@@ -1,4 +1,6 @@
 import os
+import traceback
+
 from django.apps import AppConfig
 
 from .classes.app_mixins.auto_migration_mixin import AutoMigrationMixin
@@ -11,7 +13,11 @@ class ValarConfig(AutoMigrationMixin, AutoUrlPatternsMixin, AppConfig):
 
     def ready(self):
         if os.environ.get('RUN_MAIN') == 'true':
-            from .dao.frame import MetaFrame
-            getattr(super(), 'set_url', None)()
-            getattr(super(), 'auto_migrate', None)()
-            MetaFrame()
+            try:
+                from .dao.frame import MetaFrame
+                getattr(super(), 'set_url', None)()
+                getattr(super(), 'auto_migrate', None)()
+                MetaFrame()
+            except Exception as e:
+                traceback.print_exc()
+                print('ERROR', e)
