@@ -7,7 +7,7 @@ from channels.layers import get_channel_layer
 from django.http import HttpRequest
 import threading
 from .consumer import VALAR_CHANNEL_GROUP
-from ..auth.Authentication import validate
+from ..auth.Authentication import valid_request_token
 
 
 class Channel:
@@ -19,6 +19,7 @@ class Channel:
         self.auth = body.get('auth')
         self.broadcast = body.get('broadcast')
         self.data = body.get('data')
+        self.resolve = body.get('resolve')
 
     def to_dict(self, status, payload):
         data = {
@@ -26,6 +27,7 @@ class Channel:
             'url': self.url,
             'auth': self.auth,
             'broadcast': self.broadcast,
+            'resolve': self.resolve,
             'timestamp': datetime.now().timestamp()
         }
         if status:
@@ -55,9 +57,8 @@ class ValarChannelSender(Sender):
         self.__lock__ = threading.Lock()
         self.__interval__ = interval
         if self.__channel__.auth:
-            payload, _ = validate(request)
-            if payload is None:
-                raise Exception('Unauthorized!')
+            payload = valid_request_token(request)
+            self.user_id = payload["user_id"]
 
     def _run(self):
         while self.__loading__:
