@@ -2,16 +2,19 @@ import datetime
 import json
 
 from django.core.paginator import Paginator
+from django.db.models.options import Options
 
 from .abstract import AbstractDao
 from .query import Query
-from django.db.models import ManyToOneRel, ForeignKey, ManyToManyRel, ManyToManyField, OneToOneField, OneToOneRel
+from django.db.models import ManyToOneRel, ForeignKey, ManyToManyRel, ManyToManyField, OneToOneField, OneToOneRel, \
+    CharField, BooleanField, FloatField, IntegerField, BigAutoField
 from django.db.models import QuerySet
 from django.db.models import Manager
 from django.db.models.fields.files import FieldFile
 from django.forms import FileField
 
 from ..dao.orm_field import OrmField
+from ..models.auth import Account
 from ..models.core import VTree, VModel
 from ..models.meta import MetaField
 
@@ -150,12 +153,13 @@ class OrmDao(AbstractDao):
                 m2m.clear()
                 m2m.add(*value)
             elif clazz == ManyToOneRel:
-                getattr(bean, model_field.get_accessor_name()).clear()
-                remote_model: VModel = model_field.related_model
-                new_set: QuerySet = remote_model.objects.filter(id__in=value)
-                remote_field: ForeignKey = model_field.remote_field
-                k = remote_field.get_attname()
-                new_set.update(**{k: bean.id})
+                pass
+                # getattr(bean, model_field.get_accessor_name()).clear()
+                # remote_model: VModel = model_field.related_model
+                # new_set: QuerySet = remote_model.objects.filter(id__in=value)
+                # remote_field: ForeignKey = model_field.remote_field
+                # k = remote_field.get_attname()
+                # new_set.update(**{k: bean.id})
             elif clazz == ManyToManyRel:
                 getattr(bean, model_field.get_accessor_name()).clear()
                 remote_model: VModel = model_field.related_model
@@ -207,6 +211,7 @@ class OrmDao(AbstractDao):
         # 简单字段取值
         simple_props = [field.prop for field in meta_fields if field.domain not in __referred_domains__]
         custom_props = __get_custom_props__(self.entity, code)
+
         results = list(query_set.filter().values(*[*simple_props, *custom_props]))
         __set_simple_values__(meta_fields, results)
         # 关系型字段取值
@@ -216,9 +221,72 @@ class OrmDao(AbstractDao):
         for meta_field in referred_fields:
             manager: Manager = query_set.model.objects
             qs = manager.filter(id__in=pks)
-            __linkage__(meta_field, qs, mapping)
+            self.__linkage__(meta_field, qs, mapping)
         return results
 
+    def __linkage__(self, meta_field: OrmField, query_set: QuerySet, mapping):
+        model_field = meta_field.model_field
+        prop = model_field.name
+        multiple = meta_field.domain in __multiple_domains__
+
+        # 获取级联关系的键索引
+        ref_prop = f'{prop}__id'
+        edges = query_set.exclude(**{f'{ref_prop}__isnull': True}).values('id', ref_prop)
+        if multiple:
+            related_primary_keys = set()
+            results_mapping = {}
+            for edge in edges:
+                _id, rid = edge['id'], edge[ref_prop]
+                related_primary_keys.add(rid)
+                array = results_mapping.get(_id, [])
+                array.append(rid)
+                results_mapping[_id] = array
+        else:
+            results_mapping = {row['id']: row[ref_prop] for row in edges if row[ref_prop]}
+            related_primary_keys = set(results_mapping.values())
+
+        # 获取级联关系从属方的数据
+        related_model = model_field.related_model
+        related_fields = related_model._meta.get_fields()
+        related_props = self.__get_related_props__(related_fields)
+        related_values = list(related_model.objects.filter(id__in=related_primary_keys).values(*related_props))
+        __set_simple_values__(related_fields, related_values)
+        related_mapping = {item['id']: item for item in related_values}
+
+        # 将从属方的数据绑定在主数据上
+        for _id in mapping:
+            row = mapping[_id]
+            if multiple:
+                keys = results_mapping.get(_id, [])
+                items = [related_mapping[pid] for pid in keys]
+                row[prop] = keys
+                row[f'{prop}_set'] = items
+            else:
+                key = results_mapping.get(_id)
+                item = related_mapping.get(key) if key else None
+                row[prop] = item
+                row[f'{prop}_id'] = key
+
+    def __get_related_props__(self, fields):
+        array = []
+        for field in fields:
+            domain = type(field).__name__
+            prop = field.name
+            if field.name in __omit_field_props__ or domain in __multiple_domains__:
+                continue
+            if domain in __referred_domains__:
+                field: ForeignKey = field
+                model = field.related_model
+                meta: Options = model._meta
+                if meta.label != self.entity and meta.label != 'valar.Account':
+                    _fields = meta.get_fields()
+                    for _field in _fields:
+                        if type(_field) in [CharField, BooleanField, FloatField, IntegerField, BigAutoField]:
+                            array.append(f'{prop}__{_field.name}')
+            else:
+                array.append(prop)
+        return array
+
 
 """ 以下为静态方法和变量 """
 
@@ -254,52 +322,6 @@ def __set_simple_values__(fields, values):
         for prop in json_props:
             row[prop] = json.loads(row[prop]) if type(row[prop]) is str else row[prop]
 
-
-def __get_related_props__(fields):
-    def fun(field): return type(field).__name__ not in __referred_domains__ and field.name not in __omit_field_props__
-
-    return [field.name for field in fields if fun(field)]
-
-
-def __linkage__(meta_field: OrmField, query_set: QuerySet, mapping):
-    model_field = meta_field.model_field
-    prop = model_field.name
-    multiple = meta_field.domain in __multiple_domains__
-
-    # 获取级联关系的键索引
-    ref_prop = f'{prop}__id'
-    edges = query_set.exclude(**{f'{ref_prop}__isnull': True}).values('id', ref_prop)
-    if multiple:
-        related_primary_keys = set()
-        results_mapping = {}
-        for edge in edges:
-            _id, rid = edge['id'], edge[ref_prop]
-            related_primary_keys.add(rid)
-            array = results_mapping.get(_id, [])
-            array.append(rid)
-            results_mapping[_id] = array
-    else:
-        results_mapping = {row['id']: row[ref_prop] for row in edges if row[ref_prop]}
-        related_primary_keys = set(results_mapping.values())
-
-    # 获取级联关系从属方的数据
-    related_model = model_field.related_model
-    related_fields = related_model._meta.get_fields()
-    related_props = __get_related_props__(related_fields)
-    related_values = list(related_model.objects.filter(id__in=related_primary_keys).values(*related_props))
-    __set_simple_values__(related_fields, related_values)
-    related_mapping = {item['id']: item for item in related_values}
-
-    # 将从属方的数据绑定在主数据上
-    for _id in mapping:
-        row = mapping[_id]
-        if multiple:
-            keys = results_mapping.get(_id, [])
-            items = [related_mapping[pid] for pid in keys]
-            row[prop] = keys
-            row[f'{prop}_set'] = items
-        else:
-            key = results_mapping.get(_id)
-            item = related_mapping.get(key) if key else None
-            row[prop] = item
-            row[f'{prop}_id'] = key
+    # def fun(field): return type(field).__name__ not in __referred_domains__ and field.name not in __omit_field_props__
+    #
+    # return [field.name for field in fields if fun(field)]
