@@ -1,7 +1,6 @@
-from django.urls import path
-
 from .channels.views import handel_channel
-from .views import rest, meta, file
+from .views import rest, meta, file, auth, password
+from django.urls import path
 
 urlpatterns = [
     path('socket/<str:handler>', handel_channel),
@@ -13,7 +12,6 @@ urlpatterns = [
     path('<str:db>/<str:entity>/update', rest.update),
     path('<str:db>/<str:entity>/search', rest.search),
     path('<str:db>/<str:entity>/values', rest.values),
-    # path('<str:db>/<str:entity>/tree', rest.tree),
 
     path('<str:db>/<str:entity>/meta_view', meta.meta_view),
     path('metas', meta.metas),
@@ -26,4 +24,12 @@ urlpatterns = [
     path('<str:db>/<str:entity>/save_file', file.save_file),
     path('<str:db>/<str:entity>/remove_file', file.remove_file),
 
+    path('sign_in', auth.sign_in),
+    path("user_profile", auth.user_profile),
+    path("free_menus", auth.free_menus),
+
+    path("change_password", password.change_password),
+    path("retrieve_password", password.retrieve_password),
+    path("send_password", password.send_password),
+
 ]
