@@ -1,5 +1,7 @@
 import json
 
+from django.db.models import QuerySet
+
 from .handler import batch_handler
 from ..channels.executer import execute_channel
 from ..channels.sender import ValarChannelSender
@@ -71,13 +73,13 @@ def search(request, db, entity):
     size = body.get('size')
     page = body.get('page')
     root = body.get('root')
-
-    print(root, 'root', entity)
-
     code = body.get('code', 'default')
     conditions = body.get('conditions')
     dao = Dao(entity, db)
 
+    qs, _ = dao.find(conditions)
+    qs.filter(saved=False).delete()
+
     if _type == 'tree':
         query_set = dao.tree(root, conditions)
         total = query_set.count()
